About BioSimulators-COPASI
=============================

License
-------
This package is released under the `MIT License <https://github.com/biosimulators/Biosimulators_COPASI/blob/dev/LICENSE>`_. COPASI is released under the `Artistic 2.0 License <http://copasi.org/Download/License/>`_.

Development team
----------------
This package was developed by the `Karr Lab <https://www.karrlab.org>`_ at the Icahn School of Medicine at Mount Sinai and the `Center for Cell Analysis & Modeling <https://health.uconn.edu/cell-analysis-modeling/>`_ at the University of Connecticut as part of the `Center for Reproducible Biomedical Modeling <https://reproduciblebiomodels.org/>`_. COPASI was developed by a `team <http://copasi.org/About/Team/>`_ at the University of Connecticut, the University of Heidelberg, and the University of Virginia.

Questions and comments
-------------------------
Please contact the `BioSimulators Team <mailto:info@biosimulators.org>`_ with any questions or comments about the command-line program or Docker image. Please contact the `COPASI Team <http://copasi.org/Support/User_Forum/>`_ with any questions or comments about COPASI.
